@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2022-2023, Intel Corporation
+  Copyright (c) 2022-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -111,7 +111,7 @@ IMB_JOB *
 submit_job_sha384_avx512(MB_MGR_SHA_512_OOO *state, IMB_JOB *job)
 {
         return submit_flush_job_sha_512(state, job, 8, 1, 384, IMB_SHA_512_BLOCK_SIZE,
-                                        SHA384_PAD_SIZE, call_sha512_x8_avx512_from_c);
+                                        SHA384_PAD_SIZE, call_sha512_x8_avx512_from_c, 0);
 }
 
 IMB_DLL_LOCAL
@@ -119,7 +119,7 @@ IMB_JOB *
 flush_job_sha384_avx512(MB_MGR_SHA_512_OOO *state, IMB_JOB *job)
 {
         return submit_flush_job_sha_512(state, job, 8, 0, 384, IMB_SHA_512_BLOCK_SIZE,
-                                        SHA384_PAD_SIZE, call_sha512_x8_avx512_from_c);
+                                        SHA384_PAD_SIZE, call_sha512_x8_avx512_from_c, 0);
 }
 
 /* ========================================================================== */
@@ -132,7 +132,7 @@ IMB_JOB *
 submit_job_sha512_avx512(MB_MGR_SHA_512_OOO *state, IMB_JOB *job)
 {
         return submit_flush_job_sha_512(state, job, 8, 1, 512, IMB_SHA_512_BLOCK_SIZE,
-                                        SHA512_PAD_SIZE, call_sha512_x8_avx512_from_c);
+                                        SHA512_PAD_SIZE, call_sha512_x8_avx512_from_c, 0);
 }
 
 IMB_DLL_LOCAL
@@ -140,5 +140,5 @@ IMB_JOB *
 flush_job_sha512_avx512(MB_MGR_SHA_512_OOO *state, IMB_JOB *job)
 {
         return submit_flush_job_sha_512(state, job, 8, 0, 512, IMB_SHA_512_BLOCK_SIZE,
-                                        SHA512_PAD_SIZE, call_sha512_x8_avx512_from_c);
+                                        SHA512_PAD_SIZE, call_sha512_x8_avx512_from_c, 0);
 }
