@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2022-2023, Intel Corporation
+  Copyright (c) 2022-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -50,8 +50,6 @@ is_job_invalid_light(IMB_MGR *state, const IMB_CIPHER_MODE cipher_mode, const IM
         switch (cipher_mode) {
         case IMB_CIPHER_NULL:
         case IMB_CIPHER_CUSTOM:
-        case IMB_CIPHER_SM4_CBC:
-        case IMB_CIPHER_SM4_ECB:
                 break;
         case IMB_CIPHER_CBC:
         case IMB_CIPHER_CBCS_1_9:
@@ -86,6 +84,16 @@ is_job_invalid_light(IMB_MGR *state, const IMB_CIPHER_MODE cipher_mode, const IM
                         return 1;
                 }
                 break;
+        case IMB_CIPHER_SM4_GCM:
+                if (key_len_in_bytes != UINT64_C(16)) {
+                        imb_set_errno(state, IMB_ERR_JOB_KEY_LEN);
+                        return 1;
+                }
+                if (cipher_mode == IMB_CIPHER_SM4_GCM && hash_alg != IMB_AUTH_SM4_GCM) {
+                        imb_set_errno(state, IMB_ERR_HASH_ALGO);
+                        return 1;
+                }
+                break;
         case IMB_CIPHER_DES:
         case IMB_CIPHER_DOCSIS_DES:
                 if (key_len_in_bytes != UINT64_C(8)) {
@@ -123,12 +131,10 @@ is_job_invalid_light(IMB_MGR *state, const IMB_CIPHER_MODE cipher_mode, const IM
                 }
                 break;
         case IMB_CIPHER_SNOW3G_UEA2_BITLEN:
-                if (key_len_in_bytes != UINT64_C(16)) {
-                        imb_set_errno(state, IMB_ERR_JOB_KEY_LEN);
-                        return 1;
-                }
-                break;
         case IMB_CIPHER_KASUMI_UEA1_BITLEN:
+        case IMB_CIPHER_SM4_CBC:
+        case IMB_CIPHER_SM4_ECB:
+        case IMB_CIPHER_SM4_CNTR:
                 if (key_len_in_bytes != UINT64_C(16)) {
                         imb_set_errno(state, IMB_ERR_JOB_KEY_LEN);
                         return 1;
@@ -158,6 +164,13 @@ is_job_invalid_light(IMB_MGR *state, const IMB_CIPHER_MODE cipher_mode, const IM
                         return 1;
                 }
                 break;
+        case IMB_CIPHER_CFB:
+                if (key_len_in_bytes != UINT64_C(16) && key_len_in_bytes != UINT64_C(24) &&
+                    key_len_in_bytes != UINT64_C(32)) {
+                        imb_set_errno(state, IMB_ERR_JOB_KEY_LEN);
+                        return 1;
+                }
+                break;
         default:
                 imb_set_errno(state, IMB_ERR_CIPH_MODE);
                 return 1;
@@ -217,6 +230,12 @@ is_job_invalid_light(IMB_MGR *state, const IMB_CIPHER_MODE cipher_mode, const IM
                         return 1;
                 }
                 break;
+        case IMB_AUTH_SM4_GCM:
+                if (cipher_mode != IMB_CIPHER_SM4_GCM) {
+                        imb_set_errno(state, IMB_ERR_CIPH_MODE);
+                        return 1;
+                }
+                break;
         case IMB_AUTH_AES_CCM:
                 if (cipher_mode != IMB_CIPHER_CCM) {
                         imb_set_errno(state, IMB_ERR_CIPH_MODE);
@@ -662,6 +681,45 @@ is_job_invalid(IMB_MGR *state, const IMB_JOB *job, const IMB_CIPHER_MODE cipher_
                         return -1;
                 }
                 break;
+        case IMB_CIPHER_SM4_GCM:
+                if (job->msg_len_to_cipher_in_bytes > IMB_GCM_MAX_LEN) {
+                        imb_set_errno(state, IMB_ERR_JOB_CIPH_LEN);
+                        return 1;
+                }
+                if (job->msg_len_to_cipher_in_bytes != 0 && job->src == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_SRC);
+                        return 1;
+                }
+                if (job->msg_len_to_cipher_in_bytes != 0 && job->dst == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_DST);
+                        return 1;
+                }
+                if (job->iv == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_IV);
+                        return 1;
+                }
+                if (job->iv_len_in_bytes != UINT64_C(12)) {
+                        imb_set_errno(state, IMB_ERR_JOB_IV_LEN);
+                        return 1;
+                }
+                /* Same key structure used for encrypt and decrypt */
+                if (cipher_direction == IMB_DIR_ENCRYPT && job->enc_keys == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_KEY);
+                        return 1;
+                }
+                if (cipher_direction == IMB_DIR_DECRYPT && job->dec_keys == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_KEY);
+                        return 1;
+                }
+                if (key_len_in_bytes != UINT64_C(16)) {
+                        imb_set_errno(state, IMB_ERR_JOB_KEY_LEN);
+                        return 1;
+                }
+                if (hash_alg != IMB_AUTH_SM4_GCM) {
+                        imb_set_errno(state, IMB_ERR_HASH_ALGO);
+                        return 1;
+                }
+                break;
         case IMB_CIPHER_CUSTOM:
                 /* no checks here */
                 if (job->cipher_func == NULL) {
@@ -1186,6 +1244,37 @@ is_job_invalid(IMB_MGR *state, const IMB_JOB *job, const IMB_CIPHER_MODE cipher_
                         return 1;
                 }
                 break;
+        case IMB_CIPHER_SM4_CNTR:
+                if (job->src == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_SRC);
+                        return 1;
+                }
+                if (job->dst == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_DST);
+                        return 1;
+                }
+                if (job->iv == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_IV);
+                        return 1;
+                }
+                if (job->enc_keys == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_KEY);
+                        return 1;
+                }
+                if (key_len_in_bytes != UINT64_C(16)) {
+                        imb_set_errno(state, IMB_ERR_JOB_KEY_LEN);
+                        return 1;
+                }
+                if (job->iv_len_in_bytes != UINT64_C(16) && job->iv_len_in_bytes != UINT64_C(12)) {
+                        imb_set_errno(state, IMB_ERR_JOB_IV_LEN);
+                        return 1;
+                }
+                if (job->msg_len_to_cipher_in_bytes == 0) {
+                        imb_set_errno(state, IMB_ERR_JOB_CIPH_LEN);
+                        return 1;
+                }
+                break;
+
         case IMB_CIPHER_SM4_CBC:
                 if (job->iv_len_in_bytes != UINT64_C(16)) {
                         imb_set_errno(state, IMB_ERR_JOB_IV_LEN);
@@ -1195,6 +1284,11 @@ is_job_invalid(IMB_MGR *state, const IMB_JOB *job, const IMB_CIPHER_MODE cipher_
                         imb_set_errno(state, IMB_ERR_JOB_NULL_IV);
                         return 1;
                 }
+                /* When multi-buffer implementation is added, it will limit the length */
+                if (job->msg_len_to_cipher_in_bytes > MB_MAX_LEN16) {
+                        imb_set_errno(state, IMB_ERR_JOB_CIPH_LEN);
+                        return 1;
+                }
                 /* Fall-through */
         case IMB_CIPHER_SM4_ECB:
                 if (job->src == NULL) {
@@ -1213,8 +1307,7 @@ is_job_invalid(IMB_MGR *state, const IMB_JOB *job, const IMB_CIPHER_MODE cipher_
                         imb_set_errno(state, IMB_ERR_JOB_NULL_KEY);
                         return 1;
                 }
-                if (job->msg_len_to_cipher_in_bytes == 0 ||
-                    job->msg_len_to_cipher_in_bytes > MB_MAX_LEN16) {
+                if (job->msg_len_to_cipher_in_bytes == 0) {
                         imb_set_errno(state, IMB_ERR_JOB_CIPH_LEN);
                         return 1;
                 }
@@ -1223,6 +1316,41 @@ is_job_invalid(IMB_MGR *state, const IMB_JOB *job, const IMB_CIPHER_MODE cipher_
                         return 1;
                 }
                 break;
+        case IMB_CIPHER_CFB:
+                if (job->msg_len_to_cipher_in_bytes != 0 && job->src == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_SRC);
+                        return 1;
+                }
+                if (job->msg_len_to_cipher_in_bytes != 0 && job->dst == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_DST);
+                        return 1;
+                }
+                if (job->iv == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_IV);
+                        return 1;
+                }
+                if (cipher_direction == IMB_DIR_ENCRYPT && job->enc_keys == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_KEY);
+                        return 1;
+                }
+                if (cipher_direction == IMB_DIR_DECRYPT && job->dec_keys == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_KEY);
+                        return 1;
+                }
+                if (key_len_in_bytes != UINT64_C(16) && key_len_in_bytes != UINT64_C(24) &&
+                    key_len_in_bytes != UINT64_C(32)) {
+                        imb_set_errno(state, IMB_ERR_JOB_KEY_LEN);
+                        return 1;
+                }
+                if (job->iv_len_in_bytes != UINT64_C(16)) {
+                        imb_set_errno(state, IMB_ERR_JOB_IV_LEN);
+                        return 1;
+                }
+                if (job->msg_len_to_cipher_in_bytes & UINT64_C(15)) {
+                        imb_set_errno(state, IMB_ERR_JOB_CIPH_LEN);
+                        return 1;
+                }
+                break;
         default:
                 imb_set_errno(state, IMB_ERR_CIPH_MODE);
                 return 1;
@@ -1514,9 +1642,16 @@ is_job_invalid(IMB_MGR *state, const IMB_JOB *job, const IMB_CIPHER_MODE cipher_
                         imb_set_errno(state, IMB_ERR_JOB_NULL_AUTH);
                         return 1;
                 }
-                if (job->msg_len_to_hash_in_bytes > MB_MAX_LEN16) {
-                        imb_set_errno(state, IMB_ERR_JOB_AUTH_LEN);
-                        return 1;
+                if (job->hash_alg == IMB_AUTH_AES_CMAC_BITLEN) {
+                        if (job->msg_len_to_hash_in_bits > (MB_MAX_LEN16 * 8)) {
+                                imb_set_errno(state, IMB_ERR_JOB_AUTH_LEN);
+                                return 1;
+                        }
+                } else {
+                        if (job->msg_len_to_hash_in_bytes > MB_MAX_LEN16) {
+                                imb_set_errno(state, IMB_ERR_JOB_AUTH_LEN);
+                                return 1;
+                        }
                 }
                 break;
         case IMB_AUTH_SHA_1:
@@ -1869,6 +2004,25 @@ is_job_invalid(IMB_MGR *state, const IMB_JOB *job, const IMB_CIPHER_MODE cipher_
                         return 1;
                 }
                 break;
+        case IMB_AUTH_SM4_GCM:
+                if (job->auth_tag_output_len_in_bytes < UINT64_C(1) ||
+                    job->auth_tag_output_len_in_bytes > UINT64_C(16)) {
+                        imb_set_errno(state, IMB_ERR_JOB_AUTH_TAG_LEN);
+                        return 1;
+                }
+                if ((job->u.GCM.aad_len_in_bytes > 0) && (job->u.GCM.aad == NULL)) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_AAD);
+                        return 1;
+                }
+                if (cipher_mode != IMB_CIPHER_SM4_GCM) {
+                        imb_set_errno(state, IMB_ERR_CIPH_MODE);
+                        return 1;
+                }
+                if (job->auth_tag_output == NULL) {
+                        imb_set_errno(state, IMB_ERR_JOB_NULL_AUTH);
+                        return 1;
+                }
+                break;
         default:
                 imb_set_errno(state, IMB_ERR_HASH_ALGO);
                 return 1;
