@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2018-2023, Intel Corporation
+  Copyright (c) 2018-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -45,11 +45,8 @@
 #define ALIGN(x, y) ((x + (y - 1)) & (~(y - 1)))
 
 #define OOO_INFO(imb_mgr_ooo_ptr_name__, ooo_mgr_type__)                                           \
-        {                                                                                          \
-                offsetof(IMB_MGR, imb_mgr_ooo_ptr_name__),                                         \
-                        ALIGN(sizeof(ooo_mgr_type__), ALIGNMENT),                                  \
-                        offsetof(ooo_mgr_type__, road_block)                                       \
-        }
+        { offsetof(IMB_MGR, imb_mgr_ooo_ptr_name__), ALIGN(sizeof(ooo_mgr_type__), ALIGNMENT),     \
+          offsetof(ooo_mgr_type__, road_block) }
 
 const struct {
         size_t ooo_ptr_offset;
@@ -92,7 +89,10 @@ const struct {
                       OOO_INFO(sha_384_ooo, MB_MGR_SHA_512_OOO),
                       OOO_INFO(sha_512_ooo, MB_MGR_SHA_512_OOO),
                       OOO_INFO(zuc256_eia3_8B_ooo, MB_MGR_ZUC_OOO),
-                      OOO_INFO(zuc256_eia3_16B_ooo, MB_MGR_ZUC_OOO) };
+                      OOO_INFO(zuc256_eia3_16B_ooo, MB_MGR_ZUC_OOO),
+                      OOO_INFO(aes_cfb_128_ooo, MB_MGR_AES_OOO),
+                      OOO_INFO(aes_cfb_192_ooo, MB_MGR_AES_OOO),
+                      OOO_INFO(aes_cfb_256_ooo, MB_MGR_AES_OOO) };
 
 /**
  * @brief Calculates necessary memory size for IMB_MGR.
@@ -171,7 +171,6 @@ set_ooo_mgr_road_block(IMB_MGR *mgr)
  * @param flags multi-buffer manager flags
  *     IMB_FLAG_SHANI_OFF - disable use (and detection) of SHA extensions,
  *                          currently SHANI is only available for SSE
- *     IMB_FLAG_AESNI_OFF - disable use (and detection) of AES extensions.
  *     IMB_FLAG_GFNI_OFF - disable use (and detection) of
  *                         Galois Field extensions.
  *
@@ -193,13 +192,6 @@ imb_set_pointers_mb_mgr(void *mem_ptr, const uint64_t flags, const unsigned rese
         const size_t mem_size = imb_get_mb_mgr_size();
         unsigned i;
 
-        /* Check if AESNI_EMU flag is set, needed to support AESNI emulation */
-#ifndef AESNI_EMU
-        if (flags & IMB_FLAG_AESNI_OFF) {
-                imb_set_errno(ptr, IMB_ERR_NO_AESNI_EMU);
-                return NULL;
-        }
-#endif
         if (reset_mgr) {
                 /* Zero out MB_MGR memory */
                 memset(mem_ptr, 0, mem_size);
@@ -208,21 +200,9 @@ imb_set_pointers_mb_mgr(void *mem_ptr, const uint64_t flags, const unsigned rese
 
                 /* Reset function pointers from previously used architecture */
                 switch (used_arch) {
-                case IMB_ARCH_NOAESNI:
-#ifdef AESNI_EMU
-                        init_mb_mgr_sse_no_aesni_internal(ptr, 0);
-                        break;
-#else
-                        /* Return NULL if AESNI_EMU is not enabled */
-                        imb_set_errno(ptr, IMB_ERR_NO_AESNI_EMU);
-                        return NULL;
-#endif
                 case IMB_ARCH_SSE:
                         init_mb_mgr_sse_internal(ptr, 0);
                         break;
-                case IMB_ARCH_AVX:
-                        init_mb_mgr_avx_internal(ptr, 0);
-                        break;
                 case IMB_ARCH_AVX2:
                         init_mb_mgr_avx2_internal(ptr, 0);
                         break;
@@ -282,7 +262,6 @@ free_mem(void *ptr)
  * @param flags multi-buffer manager flags
  *     IMB_FLAG_SHANI_OFF - disable use (and detection) of SHA extensions,
  *                          currently SHANI is only available for SSE
- *     IMB_FLAG_AESNI_OFF - disable use (and detection) of AES extensions.
  *     IMB_FLAG_GFNI_OFF - disable use (and detection) of
  *                         Galois Field extensions.
  *
@@ -294,13 +273,6 @@ alloc_mb_mgr(uint64_t flags)
 {
         IMB_MGR *ptr = NULL;
 
-        /* Check if AESNI_EMU flag is set, needed to support AESNI emulation */
-#ifndef AESNI_EMU
-        if (flags & IMB_FLAG_AESNI_OFF) {
-                imb_set_errno(ptr, IMB_ERR_NO_AESNI_EMU);
-                return NULL;
-        }
-#endif
         ptr = alloc_aligned_mem(imb_get_mb_mgr_size());
         IMB_ASSERT(ptr != NULL);
         if (ptr != NULL) {
