@@ -1,5 +1,5 @@
 /*****************************************************************************
- Copyright (c) 2023, Intel Corporation
+ Copyright (c) 2023-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -32,7 +32,8 @@
 
 #include <intel-ipsec-mb.h>
 #include "include/error.h"
-#include "include/sm3.h"
+#include "include/memcpy.h"
+#include "include/arch_sse_type1.h" /* sm3_one_block_sse(), sm3_msg_sse() */
 
 IMB_DLL_EXPORT
 void
@@ -102,7 +103,7 @@ imb_hmac_ipad_opad(IMB_MGR *mb_mgr, const IMB_HASH_ALG sha_type, const void *pke
 
         /* prepare the key */
         if (local_key_len == key_len) {
-                memcpy(key, pkey, key_len);
+                safe_memcpy(key, pkey, key_len);
         } else
                 switch (sha_type) {
                 case IMB_AUTH_HMAC_SHA_1:
@@ -118,7 +119,7 @@ imb_hmac_ipad_opad(IMB_MGR *mb_mgr, const IMB_HASH_ALG sha_type, const void *pke
                         IMB_SHA384(mb_mgr, pkey, key_len, key);
                         break;
                 case IMB_AUTH_HMAC_SM3:
-                        sm3_msg(key, IMB_SM3_DIGEST_SIZE, pkey, key_len);
+                        sm3_msg_sse(key, IMB_SM3_DIGEST_SIZE, pkey, key_len);
                         break;
                 default: /* For SHA-512 */
                         IMB_SHA512(mb_mgr, pkey, key_len, key);
@@ -146,7 +147,7 @@ imb_hmac_ipad_opad(IMB_MGR *mb_mgr, const IMB_HASH_ALG sha_type, const void *pke
                         IMB_SHA512_ONE_BLOCK(mb_mgr, buf, ipad_hash);
                         break;
                 case IMB_AUTH_HMAC_SM3:
-                        sm3_one_block(ipad_hash, buf);
+                        sm3_one_block_sse(ipad_hash, buf);
                         break;
                 default: /* For MD5*/
                         IMB_MD5_ONE_BLOCK(mb_mgr, buf, ipad_hash);
@@ -175,7 +176,7 @@ imb_hmac_ipad_opad(IMB_MGR *mb_mgr, const IMB_HASH_ALG sha_type, const void *pke
                         IMB_SHA512_ONE_BLOCK(mb_mgr, buf, opad_hash);
                         break;
                 case IMB_AUTH_HMAC_SM3:
-                        sm3_one_block(opad_hash, buf);
+                        sm3_one_block_sse(opad_hash, buf);
                         break;
                 default: /* For MD5 */
                         IMB_MD5_ONE_BLOCK(mb_mgr, buf, opad_hash);
