@@ -1,5 +1,5 @@
 /*****************************************************************************
- Copyright (c) 2018-2023, Intel Corporation
+ Copyright (c) 2018-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -41,6 +41,9 @@
  */
 int quiet_mode = 0;
 
+const unsigned test_num_jobs[] = { 1, 3, 4, 5, 7, 8, 9, 15, 16, 17, IMB_MAX_BURST_SIZE };
+const size_t test_num_jobs_size = DIM(test_num_jobs);
+
 /**
  * @brief Simplistic memory copy (intentionally not using libc)
  *
@@ -176,14 +179,8 @@ update_flags_and_archs(const char *arg, uint8_t arch_support[IMB_ARCH_NUM], uint
                 arch_support[IMB_ARCH_AVX512] = 0;
         else if (strcmp(arg, "--no-avx2") == 0)
                 arch_support[IMB_ARCH_AVX2] = 0;
-        else if (strcmp(arg, "--no-avx") == 0)
-                arch_support[IMB_ARCH_AVX] = 0;
         else if (strcmp(arg, "--no-sse") == 0)
                 arch_support[IMB_ARCH_SSE] = 0;
-        else if (strcmp(arg, "--aesni-emu") == 0)
-                arch_support[IMB_ARCH_NOAESNI] = 1;
-        else if (strcmp(arg, "--no-aesni-emu") == 0)
-                arch_support[IMB_ARCH_NOAESNI] = 0;
         else if (strcmp(arg, "--shani-on") == 0)
                 *flags &= (~IMB_FLAG_SHANI_OFF);
         else if (strcmp(arg, "--shani-off") == 0)
@@ -213,7 +210,6 @@ detect_arch(uint8_t arch_support[IMB_ARCH_NUM])
         const uint64_t detect_avx = IMB_FEATURE_AVX | IMB_FEATURE_CMOV | IMB_FEATURE_AESNI;
         const uint64_t detect_avx2 = IMB_FEATURE_AVX2 | detect_avx;
         const uint64_t detect_avx512 = IMB_FEATURE_AVX512_SKX | detect_avx2;
-        const uint64_t detect_noaesni = IMB_FEATURE_SSE4_2 | IMB_FEATURE_CMOV;
 
         IMB_MGR *p_mgr = NULL;
         IMB_ARCH arch_id;
@@ -223,7 +219,7 @@ detect_arch(uint8_t arch_support[IMB_ARCH_NUM])
                 return -1;
         }
 
-        for (arch_id = IMB_ARCH_NOAESNI; arch_id < IMB_ARCH_NUM; arch_id++)
+        for (arch_id = IMB_ARCH_SSE; arch_id < IMB_ARCH_NUM; arch_id++)
                 arch_support[arch_id] = 1;
 
         p_mgr = alloc_mb_mgr(0);
@@ -238,19 +234,12 @@ detect_arch(uint8_t arch_support[IMB_ARCH_NUM])
         if ((p_mgr->features & detect_avx2) != detect_avx2)
                 arch_support[IMB_ARCH_AVX2] = 0;
 
-        if ((p_mgr->features & detect_avx) != detect_avx)
-                arch_support[IMB_ARCH_AVX] = 0;
-
         if ((p_mgr->features & detect_sse) != detect_sse)
                 arch_support[IMB_ARCH_SSE] = 0;
 
-        if ((p_mgr->features & detect_noaesni) != detect_noaesni)
-                arch_support[IMB_ARCH_NOAESNI] = 0;
-
         free_mb_mgr(p_mgr);
 
-        if (arch_support[IMB_ARCH_NOAESNI] == 0 && arch_support[IMB_ARCH_SSE] == 0 &&
-            arch_support[IMB_ARCH_AVX] == 0 && arch_support[IMB_ARCH_AVX2] == 0 &&
+        if (arch_support[IMB_ARCH_SSE] == 0 && arch_support[IMB_ARCH_AVX2] == 0 &&
             arch_support[IMB_ARCH_AVX512] == 0) {
                 fprintf(stderr, "No available architecture detected!\n");
                 return -1;
@@ -268,14 +257,11 @@ detect_arch(uint8_t arch_support[IMB_ARCH_NUM])
 void
 print_tested_arch(const uint64_t features, const IMB_ARCH arch)
 {
-        static const char *arch_str_tab[IMB_ARCH_NUM] = { "NONE", "NO-AESNI", "SSE",
-                                                          "AVX",  "AVX2",     "AVX512" };
+        static const char *arch_str_tab[IMB_ARCH_NUM] = { "NONE", "SSE", "AVX2", "AVX512" };
         const char *feat = "";
 
         switch (arch) {
-        case IMB_ARCH_NOAESNI:
         case IMB_ARCH_AVX2:
-        case IMB_ARCH_AVX:
                 break;
         case IMB_ARCH_SSE:
                 if (features & IMB_FEATURE_SHANI) {
