@@ -1,5 +1,5 @@
 /*****************************************************************************
- Copyright (c) 2023, Intel Corporation
+ Copyright (c) 2023-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -214,16 +214,15 @@ int
 quic_ecb_test(struct IMB_MGR *mb_mgr)
 {
         struct test_suite_context ts128, ts256;
-        const int num_jobs_tab[] = { 1, 3, 4, 5, 7, 8, 9, 15, 16, 17 };
         unsigned i;
         int errors = 0;
 
         test_suite_start(&ts128, "QUIC-HP-AES-ECB-128");
         test_suite_start(&ts256, "QUIC-HP-AES-ECB-256");
 
-        for (i = 0; i < DIM(num_jobs_tab); i++)
+        for (i = 0; i < test_num_jobs_size; i++)
                 test_quic_ecb_vectors(mb_mgr, DIM(quic_ecb_vectors), quic_ecb_vectors,
-                                      "QUIC-HP-AES-ECB test vectors", num_jobs_tab[i], &ts128,
+                                      "QUIC-HP-AES-ECB test vectors", test_num_jobs[i], &ts128,
                                       &ts256);
 
         errors = test_suite_end(&ts128);
