@@ -1,5 +1,5 @@
 /*****************************************************************************
- Copyright (c) 2019-2023, Intel Corporation
+ Copyright (c) 2019-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -82,6 +82,12 @@ nosimd_memcpy(void *dst, const void *src, size_t n);
 uint32_t
 avx_sse_transition_check(void);
 
+/*
+ * Quick search for patterns in memory (AVX2)
+ */
+uint64_t
+mem_search_avx2(const void *ptr, const size_t size);
+
 #define MISC_AVX_SSE_YMM0_15_ISSUE (1 << 2)
 #define MISC_AVX_SSE_ZMM0_15_ISSUE (1 << 6)
 #define MISC_AVX_SSE_ISSUE         (MISC_AVX_SSE_YMM0_15_ISSUE | MISC_AVX_SSE_ZMM0_15_ISSUE)
@@ -185,6 +191,8 @@ misc_cipher_mode_to_str(const IMB_CIPHER_MODE mode)
                 return "aead-snow-v";
         case IMB_CIPHER_GCM_SGL:
                 return "aead-aes-gcm-sgl";
+        case IMB_CIPHER_CFB:
+                return "aes-cfb";
         case IMB_CIPHER_NUM:
         default:
                 break;
